@@ -3,9 +3,8 @@ from .lib.utils import Color
 from .lib.utils import symbol_ssh
 
 
-class Timer(Color):
+class Timer:
     def __init__(self, config):
-        super().__init__()
         self.timer_enable = config["timer"]["enable"]
         self.timer_symbol = symbol_ssh(config["timer"]["symbol"], "T:")
         self.timer_color = config["timer"]["color"]
